@@ -1,6 +1,6 @@
 package Dist::Zilla::PluginBundle::YANICK;
 our $AUTHORITY = 'cpan:YANICK';
-$Dist::Zilla::PluginBundle::YANICK::VERSION = '0.30.0';
+$Dist::Zilla::PluginBundle::YANICK::VERSION = '0.31.0';
 # ABSTRACT: Be like Yanick when you build your dists
 
 # [TODO] add CONTRIBUTING file
@@ -30,10 +30,6 @@ has "doap_changelog" => (
     },
 );
 
-sub not_for_travis {
-    return $ENV{TRAVIS} ? () : @_;
-}
-
 
 
 
@@ -42,29 +38,12 @@ sub not_for_travis {
 use Type::Tiny;
 use Types::Standard qw/ Str ArrayRef /;
 
+
 sub version_range {
     my( $from, $to ) = @_;
     return join ',', grep { not $_ % 2 } $from..$to;
 }
 
-my $TravisPerlVersions = Type::Tiny->new(
-    name => 'TravisPerlVersions',
-    parent => ArrayRef,
-)->plus_coercions(
-    Str ,=> sub {
-        my $vre = qr/([\d.]+)/;
-        s/$vre\.\.$vre/version_range($1,$2)/eg;
-        return [ map { '5.' . $_ } split /\s*,\s*/, $_ ];
-    },
-);
-
-has travis_perl_versions => (
-    is => 'ro',
-    isa => $TravisPerlVersions,
-    coerce => 1,
-    default => '22..30'
-);
-
 has badge => (
     isa => 'ArrayRef',
     is => 'ro',
@@ -79,6 +58,9 @@ sub configure {
     my $dev_branch     = $arg->{dev_branch}     || 'master';
     my $upstream       = $arg->{upstream}       || 'github';
 
+    my @import_from_build = $arg->{import_from_build} ? split( ',', $arg->{import_from_build} ) :
+        qw/ cpanfile AUTHOR_PLEDGE CODE_OF_CONDUCT.md /;
+
     my %mb_args;
     $mb_args{mb_class} = $arg->{mb_class} if $arg->{mb_class};
 
@@ -109,13 +91,13 @@ sub configure {
                 format    => '%-9v %{yyyy-MM-dd}d',
             } ],
         'MetaProvides::Package',
-        not_for_travis( 'MatchManifest' ),
+        'MatchManifest',
         qw/  ManifestSkip /,
         [ 'Git::GatherDir' => {
             include_dotfiles => $arg->{include_dotfiles},
-            exclude_filename => [ qw/ cpanfile AUTHOR_PLEDGE CODE_OF_CONDUCT.md /],
+            exclude_filename => [ @import_from_build ],
         } ],
-        [ CopyFilesFromBuild => { copy => [ qw/ cpanfile AUTHOR_PLEDGE CODE_OF_CONDUCT.md / ] } ],
+        [ CopyFilesFromBuild => { copy => [ @import_from_build ] } ],
         qw/ ExecDir
           PkgVersion /,
           [ Authority => {
@@ -139,13 +121,6 @@ sub configure {
                 multiple_inheritance => 1,
         } ],
         [ 'Git::Tag'  => { tag_format => 'v%v', branch => $release_branch } ],
-        [ TravisCI => [
-            verbose => 0,
-            install => 'cpanm --with-recommends --installdeps -n .',
-            script => 'prove -l t',
-
-            map { ( perl_version => $_ ) } $self->travis_perl_versions->@*
-        ]  ],
     );
 
 
@@ -174,16 +149,6 @@ sub configure {
             qw/ UploadToCPAN /,
         );
 
-        $self->add_plugins(
-            [ Twitter => {
-                tweet_url =>
-                    'https://metacpan.org/release/{{$AUTHOR_UC}}/{{$DIST}}-{{$VERSION}}/',
-                tweet =>
-                    'Released {{$DIST}}-{{$VERSION}}{{$TRIAL}} {{$URL}} !META{resources}{repository}{web}',
-                url_shortener => 'none',
-            } ],
-        ) if not defined $arg->{tweet} or $arg->{tweet};
-
         $self->add_plugins(
             [ 'InstallRelease' => { install_command => 'cpanm .' } ],
         );
@@ -210,7 +175,7 @@ sub configure {
             process_changes => $self->doap_changelog,
 #            ttl_filename => 'project.ttl',
         } ],
-        [ 'CPANFile', 'MinimumPerlFast' ],
+        'CPANFile',
     );
 
 
@@ -233,7 +198,7 @@ Dist::Zilla::PluginBundle::YANICK - Be like Yanick when you build your dists
 
 =head1 VERSION
 
-version 0.30.0
+version 0.31.0
 
 =head1 DESCRIPTION
 
@@ -326,7 +291,6 @@ his distributions. It's roughly equivalent to
     [InstallRelease]
     install_command = cpanm .
 
-    [Twitter]
     [SchwartzRatio]
 
 
@@ -336,17 +300,12 @@ his distributions. It's roughly equivalent to
     [DOAP]
     process_changes = 1
 
-    [TravisCI]
-    verbose = 0
-
     [CPANFile]
 
     [CopyrightYearFromGit]
 
     [GitHubREADME::Badge]
 
-    [MinimumPerlFast]
-
 =head2 ARGUMENTS
 
 =head3 autoprereqs_skip
@@ -363,8 +322,7 @@ If given a true value, uses L<Dist::Zilla::Plugin::FakeRelease>
 instead of
 L<Dist::Zilla::Plugin::Git::Push>,
 L<Dist::Zilla::Plugin::UploadToCPAN>,
-L<Dist::Zilla::Plugin::InstallRelease> and
-L<Dist::Zilla::Plugin::Twitter>.
+and L<Dist::Zilla::Plugin::InstallRelease>.
 
 Can also be triggered via the I<FAKE> environment variable.
 
@@ -407,15 +365,14 @@ The name of the upstream repo.
 
 Defaults to C<github>.
 
-=head3 travis_perl_versions
+=head3 import_from_build
 
-    travis_perl_versions = 22,24,26,28,30
+    import_from_build = cpanfile,AUTHOR_PLEDGE,CODE_OF_CONDUCT.md
 
-Comma-separated list of perl versions (without the leading '5') that
-travis should test. Ranges can be given (C<14..16>), for which the
-odd numbers will be skipped. So C<14..26> will result in C<14,16,18,...>.
+Comma-separated list of files to import in the checked out
+repo from the build.
 
-Defaults to C<22..30>.
+Defaults to C<cpanfile,AUTHOR_PLEDGE,CODE_OF_CONDUCT.md>
 
 =head1 AUTHOR
 
@@ -423,7 +380,7 @@ Yanick Champoux <yanick@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019, 2018, 2017, 2015, 2014, 2013, 2012, 2011, 2010 by Yanick Champoux.
+This software is copyright (c) 2025 by Yanick Champoux.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
